@@ -2,13 +2,22 @@ __author__ = "Vanessa Sochat"
 __copyright__ = "Copyright 2021-2022, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
+import shpc.utils
+
 
 def main(args, parser, extra, subparser):
 
     from shpc.main import get_client
 
+    shpc.utils.ensure_no_extra(extra)
+
     cli = get_client(quiet=args.quiet, settings_file=args.settings_file)
 
     # Update config settings on the fly
     cli.settings.update_params(args.config_params)
+
+    # One off custom registry, reload
+    if args.registry:
+        cli.settings.registry = [args.registry]
+        cli.reload_registry()
     cli.show(args.name, names_only=not args.versions, filter_string=args.filter_string)
