@@ -3,16 +3,17 @@ __copyright__ = "Copyright 2021-2022, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
 
-from shpc.logger import logger
-import shpc.main.container as container
-import shpc.utils as utils
-from .settings import Settings
-
 import os
-import re
 import shutil
 import sys
 
+import shpc.main.container as container
+import shpc.main.registry as registry
+import shpc.utils as utils
+from shpc.logger import logger
+
+from .settings import Settings
+
 
 class Client:
     """
@@ -42,12 +43,21 @@ class Client:
         if not hasattr(self, "settings"):
             self.settings = Settings(settings_file)
 
+        # Load registries from settings (into a single registry)
+        self.reload_registry()
+
     def __repr__(self):
         return str(self)
 
     def __str__(self):
         return "[shpc-client]"
 
+    def reload_registry(self):
+        """
+        Reload registry from settings.
+        """
+        self.registry = registry.Registry(self.settings)
+
     def install(self, name, tag=None, **kwargs):
         """
         Install must be implemented by the subclass (e.g., lmod)
@@ -88,15 +98,12 @@ class Client:
 
     def load_registry_config(self, name):
         """
-        Given an identifier, find the first match in the registry.
+        Given an identifier, find the first match in a registry provider.
         """
-        for registry, fullpath in self.container.iter_registry():
-            package_dir = os.path.join(registry, name)
-            package_file = os.path.join(package_dir, "container.yaml")
-            if package_file == fullpath:
-                return container.ContainerConfig(package_file)
-
-        logger.exit("%s is not a known recipe in any registry." % name)
+        result = self.registry.find(name)
+        if not result:
+            logger.exit("%s is not a known recipe in any registry." % name)
+        return container.ContainerConfig(result)
 
     def _load_container(self, name, tag=None):
         """
@@ -111,16 +118,15 @@ class Client:
         config.set_tag(tag)
         return config
 
-    def update(self, name, dryrun=False, filters=None):
+    def update(self, name=None, dryrun=False, filters=None):
         """
-        Given a module name (or None for all modules) update container.yaml files.
+        Given a module name (or None for all modules) upgrade the registry.
         """
+        # No name provided == "update all"
         if name:
             modules = [name]
-
-        # We can eventually support "update all" when we have more confidence
-        # else:
-        #    modules = [x[1] for x in list(self.container.iter_modules())]
+        else:
+            modules = [x[1] for x in list(self.registry.iter_modules())]
 
         for module_name in modules:
             config = self._load_container(module_name)
@@ -216,7 +222,7 @@ class Client:
         """
         raise NotImplementedError
 
-    def docgen(self, module_name):
+    def docgen(self, module_name, registry=None):
         """
         Render documentation for a module.
         """
@@ -234,19 +240,10 @@ class Client:
             out = out or sys.stdout
 
             # List the known registry modules
-            for registry, fullpath in self.container.iter_registry():
-                if fullpath.endswith("container.yaml"):
-                    module_name = (
-                        os.path.dirname(fullpath).replace(registry, "").strip(os.sep)
-                    )
-
-                    # If the user has provided a filter, honor it
-                    if filter_string and not re.search(filter_string, module_name):
-                        continue
-
-                    if names_only:
-                        out.write("%s\n" % module_name)
-                    else:
-                        config = self._load_container(module_name)
-                        for version in config.tags.keys():
-                            out.write("%s:%s\n" % (module_name, version))
+            for entry in self.registry.iter_registry(filter_string=filter_string):
+                config = container.ContainerConfig(entry)
+                if names_only:
+                    out.write("%s\n" % config.name)
+                else:
+                    for version in config.tags.keys():
+                        out.write("%s:%s\n" % (config.name, version))
